@@ -65,8 +65,41 @@ show_palette <- function(version_season, n = NULL, type = "logo") {
 #'   ) %>%
 #'   ggplot(aes(order, age)) +
 #'   ggpath::geom_from_path(aes(path = castaway_image_cricle), width = 0.05) +
-#'   ylim(0, 50)
+#'   ylim(0, NA)
 #'
 get_castaway_image <- function(castaway_ids, version_season) {
   glue::glue("https://gradientdescending.com/survivor/castaways/colour/{version_season}{castaway_ids}.png")
 }
+
+
+#' Check package version
+#'
+#' Compares the Github version to the system version currently loaded.
+#' The user will be informed if more up to date data exists on Github
+#'
+#' @return A message
+#' @export
+#'
+#' @importFrom utils packageVersion read.table
+#'
+#' @examples
+#' check_version()
+check_version <- function() {
+  tryCatch(
+    {
+      git_version <- suppressWarnings(read.table("https://raw.githubusercontent.com/doehm/survivoR/master/inst/version-git.txt")[1,1])
+      # git_version <- "2.0.6"
+      git <- as.numeric(strsplit(git_version, "\\.")[[1]])
+      sys_version <- as.character(utils::packageVersion("survivoR"))
+      sys <- as.numeric(strsplit(sys_version, "\\.")[[1]])
+      if(any(git - sys > 0)) {
+        msg1 <- paste0("Package version on Git (", git_version, ") is ahead of system version (", sys_version, ")\n")
+        msg2 <- "Install from Git for the latest data - devtools::install_github('doehm/survivoR')"
+        message(paste0(msg1, msg2))
+      } else {
+        message("Up to date")
+      }
+    },
+    error = function(e) message("Head to https://github.com/doehm/survivoR to check for the latest data")
+  )
+}
